@@ -5,7 +5,11 @@
 #![doc(html_logo_url = "https://avatars.githubusercontent.com/u/11549616")]
 #![doc(html_favicon_url = "https://avatars.githubusercontent.com/u/11549616")]
 
-pub use self::{resolver::StyleResolver, styles::*, traits::GraphicsStyle};
+pub use self::{
+    resolver::{StyleContext, StyleResolver},
+    styles::*,
+    traits::GraphicsStyle,
+};
 
 mod resolver;
 mod styles;
